@@ -187,6 +187,7 @@ main(int argc, char* argv[])
 	char*		prov_ifname = NULL;
 	int		prefix_len = -1;
 	struct in6_addr	addr6;
+	struct sigaction act;
 
 	/* Check the count of parameters first */
 	if (argc < 2) {
@@ -195,8 +196,13 @@ main(int argc, char* argv[])
 	}
 
 	/* set termination signal */
-	siginterrupt(SIGTERM, 1);
-	signal(SIGTERM, byebye);
+	memset(&act, 0, sizeof(struct sigaction));
+	act.sa_flags &= ~SA_RESTART; /* redundant - to stress syscalls should fail */
+	act.sa_handler = byebye;
+	if ((sigemptyset(&act.sa_mask) < 0) || (sigaction(SIGTERM, &act, NULL) < 0)) {
+		cl_log(LOG_ERR, "Could not set handler for signal: %s", strerror(errno));
+		return OCF_ERR_GENERIC;
+	}
 
 	/* open system log */
 	cl_log_set_entity(APP_NAME);
